import unittest
from vps91.src.vps91 import Vps91
from vps91.src.vps91.common import (
    DynamicGetIps as dgi,
    DynamicCheck as check,
    DynamicSetWhiteIp as dswi,
    DynamicGetWhiteIp as dgwi,
    DynamicReplaceWhiteIp as drwi,
    DynamicRemain as dr,
    DynamicBalance as db,
    UsersGetBalance as ugb,
    UsersGetAllOrders as ugao,
    UsersGetCity as ugc,
    AloneGetIps as agi,
    AloneReplaceWhiteIp as arwi,
    AloneSetWhiteIp as aswi,
    AloneGetWhiteIp as agwi,
    UnlimitedGetIps as ugi,
    UnlimitedSetWhiteIp as uswi,
    UnlimitedGetWhiteIp as ugwi,
    UnlimitedReplaceWhiteIp as urwi,
    PostPayGetIps as pgi,
    PostPayCheck as pgc,
    PostPaySetWhiteIp as pswi,
    PostPayGetWhiteIp as pgwi,
    PostPayReplaceWhiteIp as prwi,
)

dynamic_trade_no = "you dynamic trade no"
dynamic_key = "you dynamic key"

alone_trade_no = "you alone trade no"
alone_key = "you alone key"

unlimited_trade_no = "5551442918252243"
unlimited_key = "be9bdb80b1b18559a01e971f61124c92"

postPay_trade_no = "you postPay trade no"
postPay_key = "you postPay key"


class MyTestCase(unittest.TestCase):
    # 动态代理 --提取动态代理
    def test_dynamic_get_ips(self):
        m = dgi.DynamicGetIps(dynamic_key, dynamic_trade_no, "10")
        m.pt = "1"
        m.no_area = "三明"
        m.result_type = "json"
        value = Vps91.dynamic_get_ips(m)
        print(value)

    # 动态代理 -- 校验IP可用性
    def test_dynamic_check(self):
        m = check.DynamicCheck(dynamic_key, dynamic_trade_no)
        m.proxy = "1.1.1.1:8088"
        value = Vps91.dynamic_check(m)
        print(value)

    # 动态代理 -- 设置代理IP白名单
    def test_dynamic_set_white_ip(self):
        m = dswi.DynamicSetWhiteIp(dynamic_key, dynamic_trade_no)
        m.ips = "66.66.66.66"
        value = Vps91.dynamic_set_white_ip(m)
        print(value)

    # 动态代理 -- 获取IP白名单
    def test_dynamic_get_white_ip(self):
        m = dgwi.DynamicGetWhiteIp(dynamic_key, dynamic_trade_no)
        value = Vps91.dynamic_get_white_ip(m)
        print(value)

    # 动态代理 -- 修改IP白名单
    def test_dynamic_replace_white_ip(self):
        m = drwi.DynamicReplaceWhiteIp(dynamic_key, dynamic_trade_no)
        m.old_ip = "1.1.1.1"
        m.new_ip = "3.3.3.3"
        value = Vps91.dynamic_replace_white_ip(m)
        print(value)

    # 动态代理 -- 获取代理剩余可用时长
    def test_dynamic_remain(self):
        m = dr.DynamicRemain(dynamic_key, dynamic_trade_no)
        m.proxy = "12.12.12.12:8088"
        value = Vps91.dynamic_remain(m)
        print(value)

    # 动态代理 -- 获取剩余可提取IP数量
    def test_dynamic_balance(self):
        m = db.DynamicBalance(dynamic_key, dynamic_trade_no)
        value = Vps91.dynamic_balance(m)
        print(value)

    # 独享代理 -- 获取代理详情[异常]
    def test_alone_get_ips(self):
        m = agi.AloneGetIps(alone_key, alone_trade_no)
        value = Vps91.alone_get_ips(m)
        print(value)

    # 独享代理 -- 替换IP白名单
    def test_alone_replace_white_ip(self):
        m = arwi.AloneReplaceWhiteIp(alone_key, alone_trade_no)
        m.old_ip = "1.1.1.1"
        m.new_ip = "2.2.2.2"
        value = Vps91.alone_replace_white_ip(m)
        print(value)

    # 独享代理 -- 设置代理IP白名单
    def test_alone_set_white_ip(self):
        m = aswi.AloneSetWhiteIp(alone_key, alone_trade_no)
        m.ips = "66.66.66.66"
        value = Vps91.alone_set_white_ip(m)
        print(value)

    # 独享代理 -- 获取代理IP白名单
    def test_alone_get_white_ip(self):
        m = agwi.AloneGetWhiteIp(alone_key, alone_trade_no)
        value = Vps91.alone_get_white_ip(m)
        print(value)

    # 不限量 -- 获取ip
    def test_unlimited_get_ips(self):
        m = ugi.UnlimitedGetIps(unlimited_key, unlimited_trade_no, "10")
        value = Vps91.unlimited_get_ips(m)
        print(value)

    # 不限量 -- 设置白名单
    def test_unlimited_set_white_ip(self):
        m = uswi.UnlimitedSetWhiteIp(unlimited_key, unlimited_trade_no)
        m.ips = '223.6.6.6'
        value = Vps91.unlimited_set_white_ip(m)
        print(value)

    # 不限量 -- 获取白名单
    def test_unlimited_get_white_ip(self):
        m = ugwi.UnlimitedGetWhiteIp(unlimited_key, unlimited_trade_no)
        value = Vps91.unlimited_get_white_ip(m)
        print(value)

    # 不限量 -- 替换白名单
    def test_unlimited_replace_white_ip(self):
        m = urwi.UnlimitedReplaceWhiteIp(unlimited_key, unlimited_trade_no)
        m.new_ip = '223.6.6.6'
        m.old_ip = '223.6.6.6'
        value = Vps91.unlimited_replace_white_ip(m)
        print(value)

    # 按量付费 -- 获取ip
    def test_postPay_get_ips(self):
        m = pgi.PostPayGetIps(postPay_key, postPay_trade_no, "10")
        value = Vps91.postPay_get_ips(m)
        print(value)

    # 按量付费 -- 检查代理有效性
    def test_postPay_check(self):
        m = pgc.PostPayCheck(postPay_key, postPay_trade_no)
        m.proxy = "127.0.0.1:36523"
        value = Vps91.postPay_check(m)
        print(value)

    def test_postPay_set_white_ip(self):
        m = pswi.PostPaySetWhiteIp(postPay_key, postPay_trade_no)
        m.ips = '223.6.6.6'
        value = Vps91.postPay_set_white_ip(m)
        print(value)

    def test_postPay_get_white_ip(self):
        m = pgwi.PostPayGetWhiteIp(postPay_key, postPay_trade_no)
        value = Vps91.postPay_get_white_ip(m)
        print(value)

    def test_postPay_replace_white_ip(self):
        m = prwi.PostPayReplaceWhiteIp(postPay_key, postPay_trade_no)
        m.new_ip = '223.6.6.6'
        m.reset = "1"
        value = Vps91.postPay_replace_white_ip(m)
        print(value)


if __name__ == '__main__':
    unittest.main()
